# 笔记详细信息

## 查询该稿件是否禁止笔记

> https://api.bilibili.com/x/note/is_forbid

*请求方式：GET*

**url参数：**

| 参数名 | 类型 | 内容     | 必要性 | 备注 |
| ------ | ---- | -------- | ------ | ---- |
| aid    | num  | 稿件avid | 必要   |      |

**json回复：**

根对象：

| 字段    | 类型 | 内容     | 备注                        |
| ------- | ---- | -------- | --------------------------- |
| code    | num  | 返回值   | `0`成功<br />`-400`请求错误 |
| message | str  | 错误信息 | 默认为0                     |
| ttl     | num  | 1        |                             |
| data    | obj  | 信息本体 |                             |

`data`对象：

| 字段                 | 类型 | 内容         | 备注                                |
| -------------------- | ---- | ------------ | ----------------------------------- |
| forbid_note_entrance | bool | 是否禁止笔记 | `true`禁止笔记<br />`false`允许笔记 |

**示例：**

查询视频稿件`av338677252`是否禁止笔记

```shell
curl 'https://api.bilibili.com/x/note/info' \
--data-urlencode 'aid=338677252'
```

<details>
<summary>查看响应示例：</summary>
    
```json
{
    "code": 0,
    "message": "0",
    "ttl": 1,
    "data": {
        "forbid_note_entrance": false
    }
}
```

</details>

## 查询私有笔记内容

> https://api.bilibili.com/x/note/info

*请求方式：GET*

认证方式：Cookie（SESSDATA）

**url参数：**

| 参数名  | 类型 | 内容       | 必要性      | 备注     |
| ------- | ---- | ---------- | ----------- | -------- |
| oid | num | 目标id | 必要 | |
| oid_type | num | 目标id类型 | 必要 | `0`视频(oid=avid) |
| note_id | num  | 笔记id     | 必要        |          |

**json回复：**

根对象：

| 字段    | 类型 | 内容     | 备注                                                         |
| ------- | ---- | -------- | ------------------------------------------------------------ |
| code    | num  | 返回值   | `0`成功<br />`-400`请求错误<br />`-101`账号未登录<br />`79502`笔记详情未找到<br />`79503`笔记正文未找到 |
| message | str  | 错误信息 | 默认为0                                                      |
| ttl     | num  | 1        |                                                              |
| data    | obj  | 信息本体 |                                                              |

`data`对象：

| 字段         | 类型  | 内容             | 备注           |
| ------------ | ----- | ---------------- | -------------- |
| arc                  | obj   | 对应视频稿件信息 |                |
| audit_status | num   | 0                | 作用暂不明确   |
| cid_count    | num   | 视频分P数        |                |
| content      | str   | 笔记正文json序列 | 格式见[附表](readme.md#附表-笔记正文序列格式) |
| forbid_note_entrance | bool |  |  |
| pub_reason | str | 公开笔记相关原因 |  |
| pub_status | num | 公开笔记状态 | `1`未公开<br />`2`已公开<br />`4`退回 |
| pub_version | num |  |  |
| summary      | str   | 笔记预览文本     |                |
| tags         | array | 笔记跳转标签列表 |                |
| title | str | 笔记标题 | |

`data`中的`arc`对象：

| 字段     | 类型 | 内容       | 备注              |
| -------- | ---- | ---------- | ----------------- |
| oid      | num  | 目标id     |                   |
| oid_type | num  | 目标id类型 | `0`视频(oid=avid) |
| title    | str  | 视频标题   |                   |
| pic      | str  | 视频封面   |                   |
| status   | num  |            |                   |
| desc     | str  | 视频简介   |                   |

`data`中的`tags`数组：

| 项   | 类型 | 内容        | 备注             |
| ---- | ---- | ----------- | ---------------- |
| 0    | obj  | 标签1       |                  |
| n    | obj  | 标签（n+1） | 按照笔记中位置排列 |
| ……   | obj  | ……          | ……               |

`tags`中的对象：

| 字段     | 类型 | 内容              | 备注         |
| -------- | ---- | ----------------- | ------------ |
| cid      | num  | 视频cid           |              |
| status   | num  | 0                 | 作用尚不明确 |
| index    | num  | 在稿件中的分P索引 |              |
| seconds  | num  | 视频进度          |              |
| pos      | num  | 笔记中位置        |              |

**示例：**

查询视频`av338677252`中笔记`24508729145690112`的内容

```shell
curl 'https://api.bilibili.com/x/note/info' \
--data-urlencode 'oid=338677252' \
--data-urlencode 'oid_type=0' \
--data-urlencode 'note_id=24508729145690112' \
-b 'SESSDATA=xxx'
```

<details>
<summary>查看响应示例：</summary>

```json
{
    "code": 0,
    "message": "0",
    "ttl": 1,
    "data": {
        "title": "2022哔哩哔哩拜年纪",
        "summary": " ...",
        "content": "[{"insert":"\n"}]",
        "cid_count": 0,
        "audit_status": 0,
        "pub_status": 0,
        "pub_reason": "",
        "pub_version": 0,
        "forbid_note_entrance": false,
        "tags": [],
        "arc": {
            "oid": 338677252,
            "title": "2022哔哩哔哩拜年纪",
            "status": 0,
            "oid_type": 0,
            "pic": "http://i2.hdslb.com/bfs/archive/1e683a5363f35aa0a65419dbf145177099e38f90.jpg",
            "desc": ""
        }
    }
}
```

</details>

## 查询公开笔记内容

> https://api.bilibili.com/x/note/publish/info

*请求方式：GET*

**url参数：**

| 参数名 | 类型 | 内容               | 必要性 | 备注     |
| ------ | ---- | ------------------ | ------ | -------- |
| cvid   | num  | 笔记对应的专栏cvid | 必要   | 非笔记id |

**json回复：**

根对象：

| 字段    | 类型 | 内容     | 备注                                                       |
| ------- | ---- | -------- | ---------------------------------------------------------- |
| code    | num  | 返回值   | `0`成功<br />`-400`请求错误<br />`79514`公开笔记详情未找到 |
| message | str  | 错误信息 | 默认为0                                                    |
| ttl     | num  | 1        |                                                            |
| data    | obj  | 信息本体 |                                                            |

`data`对象：

| 字段                 | 类型  | 内容                   | 备注                                          |
| -------------------- | ----- | ---------------------- | --------------------------------------------- |
| cvid                 | num   | 公开笔记对应的专栏cvid |                                               |
| note_id              | num   | 笔记id                 |                                               |
| title                | str   | 笔记标题               |                                               |
| summary              | str   | 笔记预览               |                                               |
| content              | str   | 笔记正文json序列       | 格式见[附表](readme.md#附表-笔记正文序列格式) |
| cid_count            | num   | (?)                    |                                               |
| pub_status           | num   | 公开状态               |                                               |
| tags                 | array |                        |                                               |
| arc                  | obj   | 稿件信息               |                                               |
| author               | obj   | 作者信息               |                                               |
| forbid_note_entrance | bool  |                        |                                               |

`data`中的`arc`对象：

| 字段     | 类型 | 内容       | 备注              |
| -------- | ---- | ---------- | ----------------- |
| oid      | num  | 目标id     |                   |
| oid_type | num  | 目标id类型 | `0`视频(oid=avid) |
| title    | str  | 标题       |                   |
| status   | num  | (?)        |                   |
| pic      | str  | 封面url    |                   |
| desc     | str  | 简介       |                   |

`data`中的`author`对象：

| 字段     | 类型 | 内容       | 备注 |
| -------- | ---- | ---------- | ---- |
| mid      | num  | 用户mid    |      |
| name     | str  | 昵称       |      |
| face     | str  | 头像url    |      |
| level    | num  | 用户等级   |      |
| vip_info | obj  | 会员信息   |      |
| pendant  | obj  | 头像框信息 |      |

**示例：**

查看公开笔记`cv15160286`的信息

```shell
curl 'https://api.bilibili.com/x/note/publish/info' \
--data-urlencode 'cvid=15160286'
```

<details>
<summary>查看响应示例：</summary>


```json
{
    "code": 0,
    "message": "0",
    "ttl": 1,
    "data": {
        "cvid": 15160286,
        "note_id": 24114044116402190,
        "title": "2022哔哩哔哩拜年纪",
        "summary": "我决定再重新做一个系列，叫做影评系列 那么我们这一次是影系列的第n期 我也不知道是多少期，到时候回去统计一下 今天的影评是写，2022年哔哩哔哩拜年纪 【...",
        "content": "[{"insert":"我决定再重新做一个系列，叫做影评系列\n那么我们这一次是影系列的第n期\n我也不知道是多少期，到时候回去统计一下\n今天的影评是写，2022年哔哩哔哩拜年纪\n【以及往年的拜年祭，会提一下】\n看完哔哩哔哩拜年纪之后，我的触动真的很大，那今天就先写哔哩哔哩拜年纪吧。\n字数同样有点长，希望看过2022哔哩哔哩拜年纪的人可以认真看完吧！也可以说说你的想法啊！\n\n首先先说一说它的时间，因为每次都在除夕夜播放而出现要和家人看春晚，又要去抢红包之类的，所以每次都看不了直播。这一点就很糟心了。\n所以说这次同往年一样，我也是看的回放。\n一\n一开始是2233跳舞，因为我不太关注这些二次元，所以说就不详细评述了\n但是这个和去年的不问天，应该是一个系列的。都是2233在一起出镜，然后配的是一首歌，但是我觉得这首歌确实没有不问天那么惊艳我了。\n【我觉得很大的可能是今年的作曲没有泡泡老师，去年，前年的泡泡老师作的曲都真的非常的好听，而且今年的拜年纪的预告片上也有一个三首他写的歌的串烧。真的很不错。】\n二\n然后就说一下\n今年以及往年的动画\n这个主体动画真的每年做的都很不错。就是既有意义，又有故事，还有深度，同时还介绍了风俗人情和乡土民俗，真的都是非常非常好的动画，并且动画制作也很精良。\n真的想知道这些动画的主创人员都是谁，可是每次都没有标注。\n【既然谈到动画，就来说一下去年预告的一个动画叫盒中之海。其实我本来是去年看拜年纪的时候是没有看到这个预告片的\n但是今年的评论区底下，几乎每一个评论区中都在催盒中之海，于是我便去看了一下。我发现这个真的变得更有意义和深度了。\n他讲的是一个游戏，还有海神等等\n虽然感觉到它的预告片很乱，但是总觉得其中有什么联系？就是很悬疑又很惊恐但一看就很有深度的动画了！\n所以我也期待着了！】\n今年讲的是哔哩楼的故事，我觉得他的那个创意真的很好，就是自助餐厅的创意\n可以让每一个人都尝到厨师的快乐，\n但又不是真正去做厨师，如果真的能有这样一家店就好了！\n然后拜年纪传统的视频串烧节目就不说了吧。\n三\n再后来就是新春小记，俗称的是拜年曲\n去年的拜年曲是吉祥话，我觉得两个都很好听，但是说去年的都是我认识并且比较喜欢的歌手，可以今年的歌手一个都不认识了[em]e107[/em]\n但是近两年的但连许都用了说话开篇，然后其中高潮的时候都是顶针的方式来演唱，可能这也是一个习俗吧，但真的还比较好听！\n四\n一些没有触动的作品就不说了\n所以接下来是灯火！\n我没有想到今年过年能再一次听到\n《灯火里的中国》！\n因为今年春晚没有周深还有些遗憾呢！\n但虽然这首歌不是周深唱的，但也温暖人心！\n这个应该与去年的《我的祖国》是一个系列的！\n五\n四迹老师的动画一如既往的有意思\n【但就是少了灵魂快板……】\n去年和前年的快板真的深入人心了！\n所以我还是最喜欢去年的\n“这个好诶！”\n六\n邪教老师好几年没有写燃曲了哈哈哈哈哈哈\n但这个风灵玉秀和拜年祭一起做的动画挺好的\n虽然我不知道风灵玉秀是什么动画\n但武侠版的这个动画的动作做的很细致\n又不是很快，看的舒服又清晰\n配上音乐……\n【我不在想再说还不错了哈哈哈哈哈哈哈】\n七\n终于到我最喜欢的一首人演唱的歌曲\n【哈哈哈哈哈为了不与卡农冲突】\n《快乐手帐》\n我要把纳兰寻风的词吹爆！！！！！！！！！\n“跟着我，哒哒哒哒，搭个舞台\n跟着我，哒哒哒哒，大步迈开”\n“生活就是平平淡淡，偶尔磕磕绊绊\n让脑筋多转转，往好处看看！”\n真的好温暖！积极向上！向前看！\n这个初音未来的声音也没有不适感了！\n这个真的好棒！\n八\n然后是沃玛！\n沃玛的脑回路真的很独特！\n他的这个系列是视频真的很独特又新奇！\n这个不好描述……自己去看吧！\n沃玛的声音也好听！哈哈哈哈哈哈哈\n九\n魔术跳过吧\n上面是这次拜年级我最喜欢的一个节目，第大调卡农。\n这个真的很温暖，还有小提琴和钢琴的两个二重奏，就是非常的震撼人心，很感动。\n再配上他的画面，从一个小孩儿到最后的老人，感觉这一生都可以用这首歌来概括。所以说真的很感动又很温暖，\n而且这个节目的副标题是：\n致敬一生中每一个重要时刻\n所以更感动了！\n十\n拜年祭燃曲《弈》\n意境真的很扩大，不看注释完全看不懂词啊\n但去还比较好听，但感觉没有去年的《万象霜天》惊艳\n那我在b站上面看到一个视频，把这八年的八个燃曲在一起放，然后《弈》真的听起来很明显，很明显。\n高潮很高，很好听！\n所以苍穹是sv还是v啊？\n十一\n这次cilicili的《另一个我》没有做好\n可能是因为去年是《时光盲盒》真的太棒了！！！！\n“一遍遍，我回来了！……辛苦了！”\n反而今年的歌没有触动\n这是我唯一一个跳过了大约一分钟的节目\n十二\n后面几个节目都具有讽刺意义\n但那个三年都放的那个讽刺动画系列\n我属实看不懂哈哈哈哈哈哈哈哈\n梗太多了哈哈哈哈哈哈真有些看不懂\n十三\n终于到《除夕》了\n音阙诗听第二次上拜年祭！\n第一次安安和镜子演唱《与梦盛开》\n第二次是音阙诗听团队创作《除夕》\n同样是音阙诗听味啊！\n这次的词写的还不错！\n所以，节日系列开更！\n【但A-SOUL究竟是什么组合，根本没听说过啊】\n十四\n最后一个节目。\n流年如歌，是前年的最后一个节目，但是我那时候还不习惯听V曲，所以说几乎完全就跳过了，那个节目没有听。\n但是这个纳兰寻风作的词，以及这个西门振作的曲，真的配合起来好好听。\n还是要再吹一下纳兰寻风老师的词真的好棒，然后同样和上一个说的一样，温暖，感动，就有积极向上的那种乐观。\n“你是冰雪消融唤醒万物第一缕花香……”\n“湖面上小船儿晃晃岁月长……”\n【但是纳兰寻风老师究竟是做什么的？\n好像经常调教也能看到他哈哈哈哈哈哈\n没有特别关注】\n然后我每次听一听的是泠鸢翻唱的版本，这一次是让刷牙老师来唱的，男声和女声唱有有别样的风味\n这真的就像《难忘今宵》一样，要待在每一场拜年纪嘛?\n新年的那一天晚上都随着流年如歌，进入梦乡！\n人生如梦，流年似水，岁月如歌，\n春夏秋冬，年复一年\n唯有自己不变\n去下一个十年找到属于自己的答案吧！\n哔哩哔哩乾杯！\n\n\n十五【正好是十五哈哈哈哈哈】\n《五十》这个节目是很晚的时候看的\n有些悬疑，甚至有些恐怖，但引起了许多思考\n写太多了，就不详说了……\n【再次期待艾导的《盒中之海》！】\n\n哔哩哔哩( ゜ -゜)つロ 乾杯~​\n——今日发布于Q，转到哔哩哔哩！\n"}]",
        "cid_count": 0,
        "pub_status": 2,
        "tags": [],
        "arc": {
            "oid": 338677252,
            "title": "2022哔哩哔哩拜年纪",
            "status": 0,
            "oid_type": 0,
            "pic": "http://i2.hdslb.com/bfs/archive/1e683a5363f35aa0a65419dbf145177099e38f90.jpg",
            "desc": ""
        },
        "author": {
            "mid": 523870870,
            "name": "夜达星xxxxxxx",
            "face": "http://i1.hdslb.com/bfs/face/2cdfd277e63b6bb1f400ed616b5caf0a04196f28.jpg",
            "level": 3,
            "vip_info": {
                "type": 0,
                "status": 0,
                "due_date": 0,
                "vip_pay_type": 0,
                "theme_type": 0,
                "label": {
                    "path": "",
                    "text": "",
                    "label_theme": "",
                    "text_color": "",
                    "bg_style": 0,
                    "bg_color": "",
                    "border_color": ""
            	},
                "avatar_subscript": 0,
                "nickname_color": "",
                "role": 0,
                "avatar_subscript_url": ""
            },
            "pendant": {
                "pid": 0,
                "name": "",
                "image": "",
                "expire": 0,
                "image_enhance": "",
                "image_enhance_frame": ""
            }
        },
        "forbid_note_entrance": false
    }
}
```

</details>
